        function getT(rr,cc){
       if(rr==6 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260506 a 12</strong> UTC HH+120 (rango:108-132)<br><strong>control +<br>EPS</strong>';}
       if(rr==6 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260506 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>1</strong> representante: <strong>2</strong> miembros: 25 <strong>control</strong><br>0,2,3,5,8,10,11,12,13,16,17,20,23,26,27,30,32,35,36,37,39,40,43,48,50';}
       if(rr==6 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260506 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>2</strong> representante: <strong>18</strong> miembros: 15 <br>1,4,6,7,9,15,18,24,28,29,33,34,41,44,46';}
       if(rr==6 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260506 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>3</strong> representante: <strong>49</strong> miembros: 11 <br>14,19,21,22,25,31,38,42,45,47,49';}
       if(rr==29 && cc==0){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260506 a 12</strong> UTC HH+120 (rango:108-132)<br><strong>control +<br>EPS</strong>';}
       if(rr==29 && cc==1){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260506 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>1</strong> representante: <strong>2</strong> miembros: 25 <strong>control</strong><br>0,2,3,5,8,10,11,12,13,16,17,20,23,26,27,30,32,35,36,37,39,40,43,48,50';}
       if(rr==29 && cc==2){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260506 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>2</strong> representante: <strong>18</strong> miembros: 15 <br>1,4,6,7,9,15,18,24,28,29,33,34,41,44,46';}
       if(rr==29 && cc==3){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260506 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>3</strong> representante: <strong>49</strong> miembros: 11 <br>14,19,21,22,25,31,38,42,45,47,49';}
       if(rr==30 && cc==0){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260506 a 12</strong> UTC HH+120 (rango:108-132)<br><strong>control +<br>EPS</strong>';}
       if(rr==30 && cc==1){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260506 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>1</strong> representante: <strong>2</strong> miembros: 25 <strong>control</strong><br>0,2,3,5,8,10,11,12,13,16,17,20,23,26,27,30,32,35,36,37,39,40,43,48,50';}
       if(rr==30 && cc==2){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260506 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>2</strong> representante: <strong>18</strong> miembros: 15 <br>1,4,6,7,9,15,18,24,28,29,33,34,41,44,46';}
       if(rr==30 && cc==3){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260506 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>3</strong> representante: <strong>49</strong> miembros: 11 <br>14,19,21,22,25,31,38,42,45,47,49';}
       if(rr==31 && cc==0){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260506 a 12</strong> UTC HH+120 (rango:108-132)<br><strong>control +<br>EPS</strong>';}
       if(rr==31 && cc==1){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260506 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>1</strong> representante: <strong>2</strong> miembros: 25 <strong>control</strong><br>0,2,3,5,8,10,11,12,13,16,17,20,23,26,27,30,32,35,36,37,39,40,43,48,50';}
       if(rr==31 && cc==2){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260506 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>2</strong> representante: <strong>18</strong> miembros: 15 <br>1,4,6,7,9,15,18,24,28,29,33,34,41,44,46';}
       if(rr==31 && cc==3){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260506 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>3</strong> representante: <strong>49</strong> miembros: 11 <br>14,19,21,22,25,31,38,42,45,47,49';}
       if(rr==32 && cc==0){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260506 a 12</strong> UTC HH+120 (rango:108-132)<br><strong>control +<br>EPS</strong>';}
       if(rr==32 && cc==1){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260506 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>1</strong> representante: <strong>2</strong> miembros: 25 <strong>control</strong><br>0,2,3,5,8,10,11,12,13,16,17,20,23,26,27,30,32,35,36,37,39,40,43,48,50';}
       if(rr==32 && cc==2){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260506 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>2</strong> representante: <strong>18</strong> miembros: 15 <br>1,4,6,7,9,15,18,24,28,29,33,34,41,44,46';}
       if(rr==32 && cc==3){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260506 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>3</strong> representante: <strong>49</strong> miembros: 11 <br>14,19,21,22,25,31,38,42,45,47,49';}
       if(rr==33 && cc==0){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260506 a 12</strong> UTC HH+120 (rango:108-132)<br><strong>control +<br>EPS</strong>';}
       if(rr==33 && cc==1){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260506 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>1</strong> representante: <strong>2</strong> miembros: 25 <strong>control</strong><br>0,2,3,5,8,10,11,12,13,16,17,20,23,26,27,30,32,35,36,37,39,40,43,48,50';}
       if(rr==33 && cc==2){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260506 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>2</strong> representante: <strong>18</strong> miembros: 15 <br>1,4,6,7,9,15,18,24,28,29,33,34,41,44,46';}
       if(rr==33 && cc==3){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260506 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>3</strong> representante: <strong>49</strong> miembros: 11 <br>14,19,21,22,25,31,38,42,45,47,49';}
}
